cd /Users/jshim2/Dropbox/projects/passive_portfolio/replication_data/


*******************************************************************
* Generate Rebal Drivers Dataset
*******************************************************************
use active_sfq_regdata, replace

* Merge in holding period and embedded gains data
merge 1:1 fundno permno yq using holdingperiods
keep if _merge == 3
drop _merge
merge 1:1 permno fundno yq using egains
keep if _merge == 3
drop _merge

* Merge in stock trading costs data
merge m:1 permno yq using regdata_tradingcosts
keep if _merge == 3
drop _merge
rename effectivespread_percent_dw espread 
rename tsignsqrtdvol1 priceimpact 
replace espread = espread * 10000
replace priceimpact = priceimpact * sqrt(1000000)

* Merge in past flow loading changes
merge m:1 fundno yq using ../data/flow_lags
drop if _merge == 2
drop _merge

* Merge in lagged returns and alphas
merge m:1 permno yq using ../data/alphas_betas_small_lags
drop if _merge == 2
drop _merge

* Generate lags of rebal measures
capture drop g
egen g = group(fundno permno)
xtset g yq
foreach var of varlist rebalinadj* rebalout* shares {
	gen `var'_l1 = L.`var'
	replace `var'_l1 = 0 if `var'_l1 == .
}

drop egainspct egainsdollars
rename egainspct2 egainspct
replace egainspct = 10 if egainspct > 10
replace egainspct = -1 if egainspct < -1
winsor2 qret*, cuts(0.5 99.5) replace
winsor2 _4facalpha*, cuts(0.5 99.5) replace
winsor2 flowp*, cuts(0.5 99.5) replace

foreach var of varlist espread priceimpact egainspct ///
					   qret qret_l1 _4facalpha _4facalpha_l1 ///
					   l1flowp {
	drop if `var' == .
}

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

* Embedded gains rank measure
bysort fundno yq (egainspct): gen gainrank=_n
bysort fundno yq (egainspct): gen positions=_N
bysort fundno yq (egainspct): gen gainsrankp=gainrank/positions

gen qretbps = qret * 10000
gen qretl1bps = qret_l1 * 10000
gen alphaqbps = _4facalpha * 10000*62
gen alphaql1bps = _4facalpha_l1 * 10000*62

gen alphaq = _4facalpha * 62
gen alphaql1 = _4facalpha_l1 * 62

save drivers_merged, replace


*******************************************************************
* Rebal drivers regressions by category (Table 13)
*******************************************************************

* Rets
local a = 1
foreach var of varlist rebalinadja rebalinadjd rebalouta rebaloutd {
	reghdfe `var' qret qret_l1 alphaq alphaql1  if `var' != 0, ///
					absorb(fundno yq) cluster(permno fundno yq)
	if `a' == 1 {
		local a = 2
		outreg2 using _regs/rebal_drivers_v2_rets_ew, replace		
	}
	else {
		outreg2 using _regs/rebal_drivers_v2_rets_ew, append
	}
}

* Lagged rebal measures and flows
local a = 1
foreach var of varlist rebalinadja rebalinadjd rebalouta rebaloutd {
	reghdfe `var' rebalinadja_l1 rebalinadjd_l1 rebalouta_l1 flowp l1flowp ///
					if `var' != 0, ///
					absorb(fundno yq) cluster(permno fundno yq)
	if `a' == 1 {
		local a = 2
		outreg2 using _regs/rebal_drivers_v2_rebal_ew, replace		
	}
	else {
		outreg2 using _regs/rebal_drivers_v2_rebal_ew, append
	}		
}

* gains/holdingperiod
local a = 1
foreach var of varlist rebalinadja rebalinadjd rebalouta rebaloutd {
	reghdfe `var' egainspct gainsrankp holdingperiod2 ///
					if `var' != 0, ///
					absorb(fundno yq) cluster(permno fundno yq)
	if `a' == 1 {
		local a = 2
		outreg2 using _regs/rebal_drivers_v2_gains_ew, replace		
	}
	else {
		outreg2 using _regs/rebal_drivers_v2_gains_ew, append
	}
}

* trading costs
local a = 1
foreach var of varlist rebalinadja rebalinadjd rebalouta rebaloutd {
	reghdfe `var' espread if `var' != 0, ///
					absorb(fundno yq) cluster(permno fundno yq)
	if `a' == 1 {
		local a = 2
		outreg2 using _regs/rebal_drivers_v2_tcosts_ew, replace		
	}
	else {
		outreg2 using _regs/rebal_drivers_v2_tcosts_ew, append
	}
	reghdfe `var' priceimpact if `var' != 0, ///
					absorb(fundno yq) cluster(permno fundno yq)
	outreg2 using _regs/rebal_drivers_v2_tcosts_ew, append
}



