*global path="D:"
global path="C:\Users\mcsam"
cd "$path\Dropbox\passive_portfolio\data"

***************************************************
* Identify passive funds in S12 data
***************************************************

*To do this, need to map CRSP to S12
*MF Links: file maps crsp fundnos to WFICNs
use "C:\Users\mcsam\Dropbox\passive_portfolio\data\CRSP_FUNDNO-WFICN.dta",clear
keep crsp_fundno wficn 
bysort wficn (crsp_fundno): gen index=_n
reshape wide crsp_fundno,i(wficn) j(index)
save crspfundnoswide,replace

*MF Links: This file maps WFICNs to S12 fundnos
use "C:\Users\mcsam\Dropbox\passive_portfolio\data\FUNDNO-WFICN.dta" ,clear
drop if wficn==.
*unique
*duplicates tag fundno fdate,gen(tag)
*not unique
duplicates tag wficn fdate,gen(tag)
*for simplicity, drop non unique cases (less than 1%), don't need to drop from sample, however, may just be mis-labeled as active vs. passive, can account for that later
drop if tag>0
drop tag 
merge m:1 wficn using crspfundnoswide
keep if _merge==3
drop _merge
keep wficn fundno fdate crsp_fundno*
rename fundno s12fundno
reshape long crsp_fundno,i(wficn s12fundno fdate) j(index)
drop if crsp_fundno==.
save map1_2_2023,replace

*CRSP Mutual Fund: fund summary data
use "$path\Dropbox\passive_portfolio\data\fund_summary_data",clear
/*From Appel et. al. paper:
The strings we use to identify index funds are: Index, Idx, Indx, Ind_ (where _ indicates a space), Russell, S & P, S and P, S&P, SandP, SP, DOW, Dow, DJ, MSCI, Bloomberg, KBW, NASDAQ, NYSE, STOXX, FTSE, Wilshire, Morningstar, 100, 400, 500, 600, 900, 1000, 1500, 2000, and 5000.*/
gen indexstring=0
foreach name in "Index" "Idx" "Indx" "Ind " "S & P" "S and P" ///
"S&P" "SandP" "SP" "DOW" "Dow" ///
"DJ" "MSCI" "Bloomberg" "KBW" "NASDAQ" "NYSE" "STOXX" "FTSE" ///
"Wilshire" "Morningstar" "100" "400" "500" "600" "900" "1000" "1500" "2000" "5000"{
	gen t=subinstr(fund_name,"`name'","",.)
	replace indexstring=1 if t!=fund_name
	drop t
}
/*check on non-case sensitive index, only changes 84 observations, case sensitivity small issue.  Note in original paper what they do is case sensitive.*/
replace fund_name=lower(fund_name)
gen t=subinstr(fund_name,"index","",.)
replace indexstring=1 if t!=fund_name
drop t
gen passive=1 if et_flag!="" | index_fund_flag!="" | indexstring==1
replace passive=0 if passive==.
gen year=year(caldt) 
collapse (max) passive,by(crsp_fundno year)
save passiveflag,replace

use map1_2_2023,clear
gen yq=yq(year(fdate),quarter(fdate))
format yq %tq
duplicates tag crsp_fundno yq,gen(tag)
* again, duplicates are less than 1%, for simplicity remove them
drop if tag>0
drop tag
drop fdate
gen year=year(dofq(yq))
merge m:1 crsp_fundno year using passiveflag
drop if _merge==2
drop _merge
replace passive=0 if passive==.
*mark as passive if any of the share classes are considered passive
collapse (max) passive,by(s12fundno yq)
rename s12fundno fundno
*s12 fund quarter mapping to passive.  
save mapp_2_2023,replace
save "C:\Users\mcsam\Dropbox\passive_portfolio\replication_data\\passive_funds",replace
