*global path="D:"
global path="C:\Users\mcsam"
cd "$path\Dropbox\passive_portfolio\data"

**Merge s12 holdings data to CRSP

*Thompson S12: holdings data 
use "$path\Dropbox\passive_portfolio\data\s1280",clear
forvalues i=90(10)110{
	append using "$path\Dropbox\passive_portfolio\data\s12`i'"
}
*Apply fix described in the appendix with the new Thompson data
drop if year(fdate)>=2017
append using "$path\Dropbox\passive_portfolio\data\s12_2017_2022.dta" 
save temp,replace

*Break the data into 20 blocks
use temp,clear
keep fdate fundno
duplicates drop
save l1,replace
keep fundno
duplicates drop
egen g20 = xtile(fundno), n(20)
save l2,replace

*merge in the block numbers
use temp,clear
merge m:1 fundno using l2
keep if _merge==3
drop _merge
save temp,replace

*Break up by block
forvalues i=1/20{
	use * if g20==`i' using temp,clear
	save ptg`i',replace
}

*CRSP Montly Stock data: mapping between CRSP permnos and CUSIPs
use "$path\Dropbox\mainwrds\crsp\permno_cusip_map1",clear
rename *,lower
gen yq=yq(year(date),quarter(date))
format yq %tq
bysort permno yq (date): keep if _n==_N
keep permno yq cusip ncusip 

*primary is ncusip
preserve
keep permno yq ncusip
rename permno permno1
rename ncusip cusip
drop if cusip==""
save c1,replace
restore

*cusip as backup -- allows for a small number of additional matches 
keep permno yq cusip
drop if cusip==""
rename permno permno2
save c2,replace

*CRSP monthly stock data: data on cumulative factor to adjust shares
use "$path\Dropbox\passive_portfolio\data\factor",clear
append using "$path\Dropbox\passive_portfolio\data\factor2"
rename *,lower
replace shrout=shrout*1000
foreach v of varlist cfacshr cfacpr{
	replace `v'=1 if `v'==.
}
gen adjshr=shrout*cfacshr
gen adjprc=prc/cfacpr
gen yq=yq(year(date),quarter(date))
format yq %tq
bysort permno yq (date): keep if _n==_N
keep permno yq cfacshr cfacpr shrout adjshr prc adjprc
rename shrout shrout_raw
rename prc prc_raw
merge m:1 permno yq using ocsme
save factorclean_4_2023,replace

*merge blocks to CRSP
forvalues g=1/20{
	use "ptg`g'",clear
	gen yq=yq(year(fdate),quarter(fdate))
	drop fdate 
	merge m:1 cusip yq using c1
	drop if _merge==2
	drop _merge
	merge m:1 cusip yq using c2
	drop if _merge==2
	drop _merge
	gen permno=permno1
	replace permno=permno2 if permno1==.
	drop permno1 permno2
	keep if permno!=.
	drop cusip 

	collapse (sum) shares,by(permno yq fundno)

	merge m:1 permno yq using factorclean_4_2023
	keep if _merge==3
	drop _merge

	rename adjshr adjshrout
	gen adjshr=shares*cfacshr
	gen dheld=shares*abs(prc_raw)
	drop cfacpr cfacshr
	compress
	save ptg`g'_clean,replace
}

** Seperate code to keep track of match quality between S12 and CRSP
*keeps track of both # of positions matched, as well as total dollars matched 
forvalues g=1/20{
	use "ptg`g'",clear
	gen yq=yq(year(fdate),quarter(fdate))
	drop fdate 
	merge m:1 cusip yq using c1
	drop if _merge==2
	drop _merge
	merge m:1 cusip yq using c2
	drop if _merge==2
	drop _merge
	gen permno=permno1
	replace permno=permno2 if permno1==.
	drop permno1 permno2
	gen matched=1 if permno!=.
	replace matched=0 if permno==.
	gen ct=1
	*Fraction of positions
	collapse (sum) matched ct,by(fundno yq)
	gen fracmatched=matched/ct
	save fm,replace

	use ptg`g'_clean,replace
	*dollars held
	collapse (sum) dheld,by(fundno yq)
	save dh,replace

	use fm,clear
	merge 1:1 fundno yq using dh
	drop if _merge==2
	drop _merge
	save mq`g',replace
	
}

use mq1,clear
forvalues g=2/20{
	append using mq`g'
}
save mqall,replace
