cd /Users/jshim2/Dropbox/projects/passive_portfolio/replication_data


*******************************************************************
* Alphas Data
*******************************************************************
*WRDS Betas Suite: Load data on alphas and betas with respect to 1-factor, 3-factor, 4-factor models
use ../data/alphas_betas_small,clear
*CRSP index data: load data on market returns (already aggregated to the quarterly level)
merge m:1 yq using ../data/tmmkt
drop if _merge==2
drop _merge
replace qret = qret - 1
gen qretmadj=qret-cret_mkt
keep permno yq _1facalpha _3facalpha _4facalpha _4facb* qret dl qretmadj

xtset permno yq
forvalues j=1/4{
	foreach v of varlist _4facalpha {
		gen f`j'`v'=F`j'.`v'
		gen af`j'`v'= ((f`j'`v' + 1)^252-1) * 100
	}
	foreach v of varlist qret qretmadj {
		gen f`j'`v'=F`j'.`v'
		gen af`j'`v'= ((f`j'`v' + 1)^4-1) * 100
	}
}
save alphas_betas_small_f,replace


*******************************************************************
* Prepare SUE and Trading Costs Data
*******************************************************************
*IBES: Actuals and expected earnings
use ../data/earningsdata, clear
gen yq2 = yq - 1
drop yq
rename yq2 yq
format yq %tq
save earningsdata_f1, replace

*WRDS intraday indicators suite: load data on effective bid-ask spread and price impact (using millisecond TAQ data from 2003-2021)
use ../data/tradingcosts, clear
winsor2 effect* tsign*, cuts(0.5 99.5) replace
save tradingcosts, replace

*******************************************************************
* Stock-Fund-Quarter Data Processing
*******************************************************************
foreach passive in "active" "passive" {
	use all_stock_fund_quarters, clear

	replace adjprc = abs(adjprc)
	replace prc_raw = abs(prc_raw)

	drop tdheld dheld
	gen dheld = shares*abs(adjprc)
	bysort fundno yq: egen tdheld=total(dheld)

	sort fundno yq permno
	egen g = group(fundno permno)
	xtset g yq
	gen lshares_alt = lshares
	replace lshares_alt = L.fshares if dshares_alt == . & dshares_alt2 != .

	preserve
	merge m:1 fundno using flist1
	keep if _merge == 3
	drop _merge
	merge m:1 permno yq using alphas_betas_small_f
	keep if _merge == 3
	drop _merge
	* Count observations before filtering for our fund-quarters
	count if f1_4facalpha != . & _4facalpha != .
	restore

	* Merge with fund data, fund data is filtered to funds we want.
	merge m:1 fundno yq using active_fund_quarters, ///
			  keepusing(fundno yq *tna* passive expratio expfinal flowp betavw3 ///
		 		   		curralpha nextalpha vw_ret fvw_ret vw_retmadj fvw_retmadj ///
		 		   		actshare *turn* *alpha* *dollars* tr ftr r fr)
	keep if _merge == 3
	drop _merge

	merge m:1 permno yq using alphas_betas_small_f
	keep if _merge == 3
	drop _merge

	count if f1_4facalpha != . & _4facalpha != .

	compress
	save `passive'_sfq, replace
}


*******************************************************************
* Generate SFQ Regression Data
*******************************************************************
foreach passive in "active" "passive" {
	// Can use an alternative dshares variable, which correspond to 
	//	   the 3 alternative ways to handle missing data:
	// (1) dhsares_alt: treat reappearances after likely data errors 
	// 					as missing (baseline)
	// (2) dshares: treat reappearances as new fund additions
	// (3) dshares_alt2: treat reappearances as rebalin
	* foreach dsharesvar in "dshares" "dshares_alt" "dshares_alt2" {
	foreach dsharesvar in "dshares_alt" {
		
		use `passive'_sfq, clear

		drop if hasis == 1

		replace add = 0 if add == .
		replace drop = 0 if drop == .
		replace add2 = 0 if add2 == .
		replace drop2 = 0 if drop2 == .

		gen f1_4facalphabps = f1_4facalpha * 10000
		gen f2_4facalphabps = f2_4facalpha * 10000
		gen f3_4facalphabps = f3_4facalpha * 10000
		gen f4_4facalphabps = f4_4facalpha * 10000
		drop f1_4facalpha f2_4facalpha f3_4facalpha f4_4facalpha

		gen expfinalbps = expfinal * 10000
		drop expfinal 

		gen tdheldvar = e_tna * 1000000

		* Change dshares and add/drop variables based on specification
		* dshares_alt is when we treat a stock that reappears as missing
		if "`dsharesvar'" == "dshares_alt" {
			gen dropvar = drop2
			gen addvar = add2
			gen lsharesvar = lshares
		}
		* dshares_alt2 is when we treat a stock that reappears as a rebalin
		else if "`dsharesvar'" == "dshares_alt2" {
			gen dropvar = drop2
			gen addvar = add2
			gen lsharesvar = lshares_alt
		}
		* dshares is when we treat a stock that reappears as a drop then an add
		else {
			gen addvar = add
			gen dropvar = drop
			gen lsharesvar = lshares
		}


		// REBALOUT
		gen rebal_out_stock = `dsharesvar' * abs(adjprc) * 100 / tdheldvar ///
			if (addvar == 1 | dropvar == 1)
		winsor2 rebal_out_stock, cuts(.5 99.5) replace
		replace rebal_out_stock = 0 if rebal_out_stock == . & `dsharesvar' != .

		gen rebalouta = 0 if rebal_out_stock != .
		replace rebalouta = rebal_out_stock if rebal_out_stock > 0 & rebal_out_stock != .
		gen rebaloutd = 0 if rebal_out_stock != .
		replace rebaloutd = rebal_out_stock if rebal_out_stock < 0 & rebal_out_stock != .

		// REBALIN
		gen rebal_inadj_stock = (`dsharesvar' - lsharesvar * flowp) * ///
								abs(adjprc) * 100 / tdheldvar
		replace rebal_inadj_stock = . if (addvar==1 | dropvar == 1)
		winsor2 rebal_inadj_stock, cuts(.5 99.5) replace
		replace rebal_inadj_stock = 0 if (addvar==1 | dropvar == 1) & `dsharesvar' != .

		gen rebalinadja = 0 if rebal_inadj_stock != .
		replace rebalinadja = rebal_inadj_stock if rebal_inadj_stock > 0 & rebal_inadj_stock != .
		gen rebalinadjd = 0 if rebal_inadj_stock != .
		replace rebalinadjd = rebal_inadj_stock if rebal_inadj_stock < 0 & rebal_inadj_stock != .

		// REBALSCALE
		gen rebal_scale_stock = lsharesvar * flowp * abs(adjprc) * 100 / tdheldvar
		replace rebal_scale_stock = . if `dsharesvar' == .
		replace rebal_scale_stock = . if (addvar==1 | dropvar == 1)
		winsor2 rebal_scale_stock, cuts(.5 99.5) replace
		replace rebal_scale_stock = 0 if (addvar==1 | dropvar == 1) & `dsharesvar' != .

		gen rebalscalea = 0 if rebal_scale_stock != .
		replace rebalscalea = rebal_scale_stock if rebal_scale_stock > 0 & rebal_scale_stock != .
		gen rebalscaled = 0 if rebal_scale_stock != .
		replace rebalscaled = rebal_scale_stock if rebal_scale_stock < 0 & rebal_scale_stock != .


		gen f1_4facalphabpsq = f1_4facalphabps * 63
		gen f1_qretbenchadj = f1qret - ftr
		gen f1_qretbenchadjbps = f1_qretbenchadj*10000

		save `passive'_sfq_regdata_noalphadrop, replace

		drop if rebal_inadj_stock == . | rebal_out_stock == .
		drop if flowp == .
		drop if f1_4facalphabpsq == . | f1qret == .
		drop if f1_qretbenchadjbps == .

		drop lfshares has is hasis g beta* af* *_4facalpha
		
		* drop singletons
		capture drop obs
		bysort fundno yq: gen obs=_N
		drop if obs==1
		drop obs

		* compute weights
		gen wt_cf = shares * abs(adjprc)
		replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
		bysort fundno yq: egen wttot = total(wt_cf)
		gen wtfund_cf = wt_cf / wttot
		drop wt_cf wttot

		compress
		save `passive'_sfq_regdata, replace
	}
}
*/
